@@ -21,9 +21,9 @@
 something that self-voicing applications can use as their speech
 service."""
 
-__id__        = "$Id: httpserver.py,v 1.4 2006/06/14 21:46:40 wwalker Exp $"
-__version__   = "$Revision: 1.4 $"
-__date__      = "$Date: 2006/06/14 21:46:40 $"
+__id__        = "$Id: httpserver.py 2504 2007-06-26 20:30:05Z richb $"
+__version__   = "$Revision: 2504 $"
+__date__      = "$Date: 2007-06-26 16:30:05 -0400 (Tue, 26 Jun 2007) $"
 __copyright__ = "Copyright (c) 2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -51,6 +51,11 @@ class _HTTPRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
 
     """
 
+    def log_request(self, code=None, size=None):
+        """Override to avoid getting a log message on stdout for
+        each GET, POST, etc. request"""
+        pass
+        
     def do_GET(self):
         self.send_response(200)
         self.send_header("Content-type", "text/html")
@@ -85,10 +90,32 @@ class _HTTPRequestThread(threading.Thread):
     """Runs a _HTTPRequestHandler in a separate thread."""
 
     def run(self):
-        httpd = BaseHTTPServer.HTTPServer(('',
-                                           settings.httpServerPort),
-                                          _HTTPRequestHandler)
-        httpd.serve_forever()
+        """Try to start an HTTP server on settings.httpServerPort.
+        If this fails, retry settings.maxHttpServerRetries times,
+        each time incrementing the server port number by 1. If we
+        are still unable to start a server, just fail gracefully.
+        """
+
+        portNo = settings.httpServerPort
+        connected = False
+        while not connected and \
+            (portNo < settings.httpServerPort + settings.maxHttpServerRetries):
+            try:
+                httpd = BaseHTTPServer.HTTPServer(('', portNo),
+                                                  _HTTPRequestHandler)
+                connected = True
+            except:
+                if portNo == settings.httpServerPort:
+                    debug.printException(debug.LEVEL_WARNING)
+                debug.println(debug.LEVEL_WARNING,
+                    "httpserver._HTTPRequestThread unable to start server on port %d" % portNo)
+                portNo += 1
+
+        if not connected:
+            debug.println(debug.LEVEL_WARNING,
+                    "httpserver._HTTPRequestThread server startup failed.")
+        else:
+            httpd.serve_forever()
 
 def init():
     """Creates an HTTP server that listens for speak commands from a
@@ -103,7 +130,7 @@ def init():
             _httpRequestThread.setDaemon(True)
             _httpRequestThread.start()
         except:
-            debug.printException(debug.LEVEL_SEVERE)
+            debug.printException(debug.LEVEL_WARNING)
 
 def shutdown():
     """Stops the HTTP server.  [[[WDW - not implemented yet.]]]"""
