@@ -23,9 +23,9 @@ class.  For those wishing to override the speech generators, however,
 one can create a new instance and replace/extend the speech generators
 as they see fit."""
 
-__id__        = "$Id: speechgenerator.py 2487 2007-06-19 23:10:50Z richb $"
-__version__   = "$Revision: 2487 $"
-__date__      = "$Date: 2007-06-19 19:10:50 -0400 (Tue, 19 Jun 2007) $"
+__id__        = "$Id: speechgenerator.py 2539 2007-07-13 18:32:02Z richb $"
+__version__   = "$Revision: 2539 $"
+__date__      = "$Date: 2007-07-13 14:32:02 -0400 (Fri, 13 Jul 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -1364,6 +1364,21 @@ class SpeechGenerator:
                         showing = cell.state.count( \
                                           atspi.Accessibility.STATE_SHOWING)
                         if showing:
+                            # If this table cell has a "toggle" action, and
+                            # doesn't have any label associated with it then 
+                            # also speak the table column header.
+                            # See Orca bug #455230 for more details.
+                            #
+                            label = self._script.getDisplayedText( \
+                                self._script.getRealActiveDescendant(cell))
+                            action = cell.action
+                            if action and (label == None or len(label) == 0):
+                                for j in range(0, action.nActions):
+                                    if action.getName(j) == "toggle":
+                                        header = parent.table.getColumnHeader(i)
+                                        accHeader = atspi.Accessible.makeAccessible(header)
+                                        utterances.append(accHeader.name)
+
                             utterances.extend(self._getSpeechForTableCell(cell,
                                                            already_focused))
                 else:
